==> ts-util-v1_0_0-env.tar.gz: ts-util-v1_0_0-env/src/ts/util/text/EndWithEscapeCharException.java <==
/*
 * EndWithEscapeCharException class.
 *
 * Copyright (C) 2007 SATOH Takayuki All Rights Reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
package ts.util.text;

/**
 * 񂪃GXP[vŏIĂꍇɃX[ONXB:w
 *
 * @author  V. 
 * @version $Revision: 1.2 $, $Date: 2007/02/15 15:28:05 $
 */
public class EndWithEscapeCharException extends StringConvertException
{
  /** VAԍB */
  static final long serialVersionUID = -407402062068943328L;

  /**
   * OCfbNXƁA܂łɕϊꂽɂƂ
   * RXgN^B
   *
   * @param  index OCfbNXB
   * @param  converted ϊꂽB
   */
  public EndWithEscapeCharException(int index, String converted)
  {
    super(index, converted);
  }

  /**
   * OCfbNXƁA܂łɕϊꂽAObZ[W
   * ɂƂRXgN^B
   *
   * @param  index OCfbNXB
   * @param  converted ϊꂽB
   * @param  msg ObZ[WB
   */
  public EndWithEscapeCharException(int index, String converted, String msg)
  {
    super(index, converted, msg);
  }
}

==> ts-util-1.1.0.env.tar.gz: ts-util-1.1.0.env/src/ts/util/text/EndWithEscapeCharException.java <==
/*
 * EndWithEscapeCharException class.
 *
 * Copyright (C) 2007 SATOH Takayuki All Rights Reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
package ts.util.text;

/**
 * 񂪃GXP[vŏIĂꍇɃX[ONXB
 *
 * @author  V. 
 * @version $Revision: 1.3 $, $Date: 2007/05/27 16:13:16 $
 */
public class EndWithEscapeCharException extends StringConvertException
{
  /** VAԍB */
  static final long serialVersionUID = -407402062068943328L;

  /**
   * OCfbNXƁA܂łɕϊꂽɂƂ
   * RXgN^B
   * <br>
   * ȂAłCfbNXƂ́AR[hE|CgPʂ̒lłB
   *
   * @param  index OCfbNXB
   * @param  converted O܂łɕϊꂽB
   */
  public EndWithEscapeCharException(int index, CharSequence converted)
  {
    super(index, converted);
  }

  /**
   * OCfbNXƁA܂łɕϊꂽAObZ[W
   * ɂƂRXgN^B
   * <br>
   * ȂAłCfbNXƂ́AR[hE|CgPʂ̒lłB
   *
   * @param  index OCfbNXB
   * @param  converted O܂łɕϊꂽB
   * @param  msg ObZ[WB
   */
  public EndWithEscapeCharException(
    int index, CharSequence converted, String msg)
  {
    super(index, converted, msg);
  }
}
